@@ -18,6 +18,20 @@
 extern "C" {
 #endif
 
+/**
+ * @ingroup gearman_server_client
+ */
+struct gearman_server_client_st
+{
+  gearman_server_client_options_t options;
+  gearman_server_con_st *con;
+  gearman_server_client_st *con_next;
+  gearman_server_client_st *con_prev;
+  gearman_server_job_st *job;
+  gearman_server_client_st *job_next;
+  gearman_server_client_st *job_prev;
+};
+
 /**
  * @addtogroup gearman_server_client Client Declarations
  * @ingroup gearman_server
