@@ -28,6 +28,27 @@ extern "C" {
  * @{
  */
 
+/**
+ * @ingroup gearman_server_function
+ */
+struct gearman_server_function_st
+{
+  gearman_server_function_options_t options;
+  uint32_t worker_count;
+  uint32_t job_count;
+  uint32_t job_total;
+  uint32_t job_running;
+  uint32_t max_queue_size;
+  size_t function_name_size;
+  gearman_server_st *server;
+  gearman_server_function_st *next;
+  gearman_server_function_st *prev;
+  char *function_name;
+  gearman_server_worker_st *worker_list;
+  gearman_server_job_st *job_list[GEARMAN_JOB_PRIORITY_MAX];
+  gearman_server_job_st *job_end[GEARMAN_JOB_PRIORITY_MAX];
+};
+
 /**
  * Add a new function to a server instance.
  */
