@@ -157,7 +157,7 @@ void gearmand_set_threads(gearmand_st *gearmand, uint32_t threads)
 }
 
 void gearmand_set_log_fn(gearmand_st *gearmand, gearman_log_fn *function,
-                         const void *context, gearman_verbose_t verbose)
+                         void *context, gearman_verbose_t verbose)
 {
   gearman_server_set_log_fn(&(gearmand->server), _log, gearmand, verbose);
   gearmand->log_fn= function;
@@ -166,7 +166,7 @@ void gearmand_set_log_fn(gearmand_st *gearmand, gearman_log_fn *function,
 }
 
 gearman_return_t gearmand_port_add(gearmand_st *gearmand, in_port_t port,
-                                   gearman_con_add_fn *function)
+                                   gearman_connection_add_fn *function)
 {
   gearmand_port_st *port_list;
 
@@ -280,6 +280,17 @@ void gearmand_wakeup(gearmand_st *gearmand, gearmand_wakeup_t wakeup)
     GEARMAN_ERROR(gearmand, "gearmand_wakeup:write:%d", errno)
 }
 
+void gearmand_set_round_robin(gearmand_st *gearmand, bool round_robin)
+{
+  if (round_robin)
+  {
+    gearmand->server.options|= GEARMAN_SERVER_RR_ORDER;
+    return;
+  }
+  gearmand->server.options&= GEARMAN_SERVER_RR_ORDER;
+}
+
+
 /*
  * Private definitions
  */
@@ -484,13 +495,15 @@ static void _listen_clear(gearmand_st *gearmand)
   if (!(gearmand->options & GEARMAND_LISTEN_EVENT))
     return;
 
+  int del_ret= 0;
   for (x= 0; x < gearmand->port_count; x++)
   {
     for (y= 0; y < gearmand->port_list[x].listen_count; y++)
     {
       GEARMAN_INFO(gearmand, "Clearing event for listening socket (%d)",
                    gearmand->port_list[x].listen_fd[y])
-      assert(event_del(&(gearmand->port_list[x].listen_event[y])) == 0);
+      del_ret= event_del(&(gearmand->port_list[x].listen_event[y]));
+      assert(del_ret == 0);
     }
   }
 
@@ -615,7 +628,8 @@ static void _wakeup_clear(gearmand_st *gearmand)
   if (gearmand->options & GEARMAND_WAKEUP_EVENT)
   {
     GEARMAN_INFO(gearmand, "Clearing event for wakeup pipe")
-    assert(event_del(&(gearmand->wakeup_event)) == 0);
+    int del_ret= event_del(&(gearmand->wakeup_event));
+    assert(del_ret == 0);
     gearmand->options&= (gearmand_options_t)~GEARMAND_WAKEUP_EVENT;
   }
 }
