@@ -28,6 +28,49 @@ extern "C" {
  * @{
  */
 
+
+/**
+ * @ingroup gearman_client
+ */
+struct gearman_client_st
+{
+  struct {
+    bool allocated LIBGEARMAN_BITFIELD;
+    bool non_blocking LIBGEARMAN_BITFIELD;
+    bool task_in_use LIBGEARMAN_BITFIELD;
+    bool unbuffered_result LIBGEARMAN_BITFIELD;
+    bool no_new LIBGEARMAN_BITFIELD;
+    bool free_tasks LIBGEARMAN_BITFIELD;
+  } options;
+  enum {
+    GEARMAN_CLIENT_STATE_IDLE,
+    GEARMAN_CLIENT_STATE_NEW,
+    GEARMAN_CLIENT_STATE_SUBMIT,
+    GEARMAN_CLIENT_STATE_PACKET
+  } state;
+  gearman_return_t do_ret;
+  uint32_t new_tasks;
+  uint32_t running_tasks;
+  uint32_t task_count;
+  size_t do_data_size;
+  void *context;
+  gearman_connection_st *con;
+  gearman_task_st *task;
+  gearman_task_st *task_list;
+  gearman_task_context_free_fn *task_context_free_fn;
+  void *do_data;
+  gearman_workload_fn *workload_fn;
+  gearman_created_fn *created_fn;
+  gearman_data_fn *data_fn;
+  gearman_warning_fn *warning_fn;
+  gearman_universal_status_fn *status_fn;
+  gearman_complete_fn *complete_fn;
+  gearman_exception_fn *exception_fn;
+  gearman_fail_fn *fail_fn;
+  gearman_universal_st universal;
+  gearman_task_st do_task;
+};
+
 /**
  * Initialize a client structure. Always check the return value even if passing
  * in a pre-allocated structure. Some other initialization may have failed. It
@@ -116,13 +159,13 @@ void gearman_client_remove_options(gearman_client_st *client,
                                    gearman_client_options_t options);
 
 /**
- * See gearman_timeout() for details.
+ * See gearman_universal_timeout() for details.
  */
 GEARMAN_API
 int gearman_client_timeout(gearman_client_st *client);
 
 /**
- * See gearman_set_timeout() for details.
+ * See gearman_universal_set_timeout() for details.
  */
 GEARMAN_API
 void gearman_client_set_timeout(gearman_client_st *client, int timeout);
@@ -145,31 +188,23 @@ void *gearman_client_context(const gearman_client_st *client);
  * @param[in] context Application context to set.
  */
 GEARMAN_API
-void gearman_client_set_context(gearman_client_st *client, const void *context);
+void gearman_client_set_context(gearman_client_st *client, void *context);
 
 /**
  * See gearman_set_log_fn() for details.
  */
 GEARMAN_API
 void gearman_client_set_log_fn(gearman_client_st *client,
-                               gearman_log_fn *function, const void *context,
+                               gearman_log_fn *function, void *context,
                                gearman_verbose_t verbose);
 
-/**
- * See gearman_set_event_watch_fn() for details.
- */
-GEARMAN_API
-void gearman_client_set_event_watch_fn(gearman_client_st *client,
-                                       gearman_event_watch_fn *function,
-                                       const void *context);
-
 /**
  * See gearman_set_workload_malloc_fn() for details.
  */
 GEARMAN_API
 void gearman_client_set_workload_malloc_fn(gearman_client_st *client,
                                            gearman_malloc_fn *function,
-                                           const void *context);
+                                           void *context);
 
 /**
  * See gearman_set_workload_malloc_fn() for details.
@@ -177,7 +212,7 @@ void gearman_client_set_workload_malloc_fn(gearman_client_st *client,
 GEARMAN_API
 void gearman_client_set_workload_free_fn(gearman_client_st *client,
                                          gearman_free_fn *function,
-                                         const void *context);
+                                         void *context);
 
 /**
  * Add a job server to a client. This goes into a list of servers that can be
@@ -198,7 +233,7 @@ gearman_return_t gearman_client_add_server(gearman_client_st *client,
  * SERVER[:PORT][,SERVER[:PORT]]...
  * Some examples are:
  * 10.0.0.1,10.0.0.2,10.0.0.3
- * localhost:1234,jobserver2.domain.com:7003,10.0.0.3
+ * localhost LIBGEARMAN_BITFIELD234,jobserver2.domain.com:7003,10.0.0.3
  *
  * @param[in] client Structure previously initialized with
  *  gearman_client_create() or gearman_client_clone().
@@ -402,15 +437,6 @@ gearman_return_t gearman_client_echo(gearman_client_st *client,
  * @{
  */
 
-/**
- * Free a task structure.
- *
- * @param[in] task Structure previously initialized with one of the
- *  gearman_client_add_task() functions.
- */
-GEARMAN_API
-void gearman_task_free(gearman_task_st *task);
-
 /**
  * Free all tasks for a gearman structure.
  *
@@ -430,7 +456,7 @@ void gearman_client_task_free_all(gearman_client_st *client);
  */
 GEARMAN_API
 void gearman_client_set_task_context_free_fn(gearman_client_st *client,
-                                        gearman_task_context_free_fn *function);
+                                             gearman_task_context_free_fn *function);
 
 /**
  * Add a task to be run in parallel.
@@ -450,7 +476,7 @@ void gearman_client_set_task_context_free_fn(gearman_client_st *client,
 GEARMAN_API
 gearman_task_st *gearman_client_add_task(gearman_client_st *client,
                                          gearman_task_st *task,
-                                         const void *context,
+                                         void *context,
                                          const char *function_name,
                                          const char *unique,
                                          const void *workload,
@@ -464,7 +490,7 @@ gearman_task_st *gearman_client_add_task(gearman_client_st *client,
 GEARMAN_API
 gearman_task_st *gearman_client_add_task_high(gearman_client_st *client,
                                               gearman_task_st *task,
-                                              const void *context,
+                                              void *context,
                                               const char *function_name,
                                               const char *unique,
                                               const void *workload,
@@ -478,7 +504,7 @@ gearman_task_st *gearman_client_add_task_high(gearman_client_st *client,
 GEARMAN_API
 gearman_task_st *gearman_client_add_task_low(gearman_client_st *client,
                                              gearman_task_st *task,
-                                             const void *context,
+                                             void *context,
                                              const char *function_name,
                                              const char *unique,
                                              const void *workload,
@@ -492,7 +518,7 @@ gearman_task_st *gearman_client_add_task_low(gearman_client_st *client,
 GEARMAN_API
 gearman_task_st *gearman_client_add_task_background(gearman_client_st *client,
                                                     gearman_task_st *task,
-                                                    const void *context,
+                                                    void *context,
                                                     const char *function_name,
                                                     const char *unique,
                                                     const void *workload,
@@ -507,7 +533,7 @@ GEARMAN_API
 gearman_task_st *
 gearman_client_add_task_high_background(gearman_client_st *client,
                                         gearman_task_st *task,
-                                        const void *context,
+                                        void *context,
                                         const char *function_name,
                                         const char *unique,
                                         const void *workload,
@@ -522,7 +548,7 @@ GEARMAN_API
 gearman_task_st *
 gearman_client_add_task_low_background(gearman_client_st *client,
                                        gearman_task_st *task,
-                                       const void *context,
+                                       void *context,
                                        const char *function_name,
                                        const char *unique,
                                        const void *workload,
@@ -544,7 +570,7 @@ gearman_client_add_task_low_background(gearman_client_st *client,
 GEARMAN_API
 gearman_task_st *gearman_client_add_task_status(gearman_client_st *client,
                                                 gearman_task_st *task,
-                                                const void *context,
+                                                void *context,
                                                 const char *job_handle,
                                                 gearman_return_t *ret_ptr);
 
@@ -601,7 +627,7 @@ void gearman_client_set_warning_fn(gearman_client_st *client,
  */
 GEARMAN_API
 void gearman_client_set_status_fn(gearman_client_st *client,
-                                  gearman_status_fn *function);
+                                  gearman_universal_status_fn *function);
 
 /**
  * Callback function when a task is complete.
