@@ -17,7 +17,7 @@
 #include "test_worker.h"
 
 pid_t test_worker_start(in_port_t port, const char *function_name,
-                        gearman_worker_fn *function, const void *function_arg)
+                        gearman_worker_fn *function, void *function_arg)
 {
   pid_t worker_pid;
   gearman_worker_st worker;
@@ -31,13 +31,14 @@ pid_t test_worker_start(in_port_t port, const char *function_name,
     assert(gearman_worker_add_server(&worker, NULL, port) == GEARMAN_SUCCESS);
     assert(gearman_worker_add_function(&worker, function_name, 0, function,
            function_arg) == GEARMAN_SUCCESS);
+
     while (1)
     {
       gearman_return_t ret= gearman_worker_work(&worker);
       assert(ret == GEARMAN_SUCCESS);
     }
 
-    /* TODO: unreachable - the only way out of the loop above is the assert 
+    /* TODO: unreachable - the only way out of the loop above is the assert
      * gearman_worker_free(&worker);
      * exit(0);
      */
